==> 4.4.3.tar.gz: terraform-provider-decort/samples/cloudapi/data_account_rg_list/main.tf <==
/*
Пример использования
Получение информации о ресурных группах, используемых аккаунтом
*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/

provider "decort" {
  authenticator = "oauth2"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_account_rg_list" "argl" {
  #id аккаунта
  #обязательный параметр
  #тип - число
  account_id = 66666

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 3

  #фильтр по id ресурсной группы
  #опциональный параметр 
  #тип - число
  #rg_id = 11111

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id vins
  #опциональный параметр
  #тип - число
  #vins_id = 100

  #фильтр по id compute
  #опциональный параметр
  #тип - число
  #vm_id = 100

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "CREATED"
}

output "test" {
  value = data.decort_account_rg_list.argl
}

==> 4.5.0.tar.gz: terraform-provider-decort/samples/cloudapi/data_account_rg_list/main.tf <==
/*
Пример использования
Получение информации о ресурных группах, используемых аккаунтом
*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_account_rg_list" "argl" {
  #id аккаунта
  #обязательный параметр
  #тип - число
  account_id = 66666

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 2

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 3

  #фильтр по id ресурсной группы
  #опциональный параметр 
  #тип - число
  #rg_id = 11111

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по id vins
  #опциональный параметр
  #тип - число
  #vins_id = 100

  #фильтр по id compute
  #опциональный параметр
  #тип - число
  #vm_id = 100

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "CREATED"
}

output "test" {
  value = data.decort_account_rg_list.argl
}
